@@ -25,7 +25,7 @@ from multiprocessing import Pool
 import tqdm
 import traceback
 from functools import partial
-
+import pathlib
 
 metadata_columns = ["date_uploaded",
                     "date_created",
@@ -738,7 +738,7 @@ def upload_files(dat, unfold=True):
                                   "mounting method": get_meta_value(meta, "mount"),
                                   "protocol": get_meta_value(meta, "protocol"),
                                   "user_meta1": get_meta_value(meta, "usermeta1"),
-                                  "user_meta2": get_meta_value(meta, "usermeta2"),
+                                  "user_meta2": get_meta_value(meta, "usermeta1"),
                                   "user_meta3": get_meta_value(meta, "usermeta3"),
                                   "folder": get_meta_value(meta, "folder"),
                                   "parent_folder": get_meta_value(meta, "parent_folder"),
@@ -778,123 +778,154 @@ def extract_list(data, mode="file"):
 user_initial = "CF"
 
 
-files = glob(r"D:\DFP Data\100223_ConorDFP_Plate2_NR+DAPI\Agarose Pillar_001\data\*.xml")  
+files = glob(r"D:\AKSEG Images\Images\Conor\Conor_DFP_NIM\**\*.tif")  
+
+
+path = files[0]
+
+
+file_name = os.path.basename(path)
+
+
+folders = pathlib.Path(path).parts
+
+folder = folders[-1]
+parent_folder = folders[-2]
+
+if "holdout" in parent_folder.lower():
+    usermeta2 = "train"
+else:
+    usermeta2 = "test"
+
+
+
+
+
+
+
+
 # files = glob(r"D:\DFP Data\080223_ConorDFP_Plate1_NR+DAPI\Agarose Pillar_001\data\*.xml")  
 
 
-file_data = read_xml(files)
 
 
 
-upload_data = []
 
-for file_name,data in file_data.items():
+
+
+# file_data = read_xml(files)
+
+
+
+# upload_data = []
+
+# for file_name,data in file_data.items():
     
-    well_position_name = data["well_position_name_transpose"]
+#     well_position_name = data["well_position_name_transpose"]
     
-    column = well_position_name[0]
-    row = int(well_position_name[1:])
+#     column = well_position_name[0]
+#     row = int(well_position_name[1:])
     
-    if column=="A":
-        antibiotic = "None"
-        antibiotic_contration = ""
-    elif column=="B":
-        antibiotic = "Ciprofloxacin"
-        antibiotic_contration = "10XEUCAST"
-    elif column=="C":
-        antibiotic = "Gentamicin"
-        antibiotic_contration = "10XEUCAST"
-    elif column=="D":
-        antibiotic = "Ceftriaxone"
-        antibiotic_contration = "3XEUCAST"
-    elif column=="E":
-        antibiotic = "Ciprofloxacin"
-        antibiotic_contration = "1XEUCAST"
+#     if column=="A":
+#         antibiotic = "None"
+#         antibiotic_contration = ""
+#     elif column=="B":
+#         antibiotic = "Ciprofloxacin"
+#         antibiotic_contration = "10XEUCAST"
+#     elif column=="C":
+#         antibiotic = "Gentamicin"
+#         antibiotic_contration = "10XEUCAST"
+#     elif column=="D":
+#         antibiotic = "Ceftriaxone"
+#         antibiotic_contration = "3XEUCAST"
+#     elif column=="E":
+#         antibiotic = "Ciprofloxacin"
+#         antibiotic_contration = "1XEUCAST"
         
-    if row in [1,2]:
-        repeat = 1
-        usermeta3 = f"{repeat}-{[1,2].index(row)+1}"
-    if row in [3,4]:
-        repeat = 2
-        usermeta3 = f"{repeat}-{[3,4].index(row)+1}"
-    if row in [5,6]:
-        repeat = 3
-        usermeta3 = f"{repeat}-{[5,6].index(row)+1}"
-    if row in [7,8]:
-        repeat = 4
-        usermeta3 = f"{repeat}-{[7,8].index(row)+1}"
+#     if row in [1,2]:
+#         repeat = 1
+#         usermeta3 = f"{repeat}-{[1,2].index(row)+1}"
+#     if row in [3,4]:
+#         repeat = 2
+#         usermeta3 = f"{repeat}-{[3,4].index(row)+1}"
+#     if row in [5,6]:
+#         repeat = 3
+#         usermeta3 = f"{repeat}-{[5,6].index(row)+1}"
+#     if row in [7,8]:
+#         repeat = 4
+#         usermeta3 = f"{repeat}-{[7,8].index(row)+1}"
         
-    if column in ["A","B"]:
-        strain = "L48480"
-    elif column in ["C","D"]:
-        strain = "L11037"
-    else:
-        strain = ""
+#     if column in ["A","B"]:
+#         strain = "L48480"
+#     elif column in ["C","D"]:
+#         strain = "L11037"
+#     else:
+#         strain = ""
         
-    if data["time_index"]==0:
+#     if data["time_index"]==0:
         
-        file_data[file_name]["user_initial"] = user_initial
-        file_data[file_name]["antibiotic"] = antibiotic
-        file_data[file_name]["abxconcentration"] = antibiotic_contration
-        file_data[file_name]["repeat"] = repeat
-        file_data[file_name]["usermeta1"] = "Direct From Plate"
-        file_data[file_name]["usermeta2"] = "Plate2"
-        file_data[file_name]["usermeta3"] = usermeta3
-        file_data[file_name]["protocol"] = ""
-        file_data[file_name]["image_content"] = "E.Coli"
-        file_data[file_name]["mount"] = "Agarose Pillars"
-        file_data[file_name]["strain"] = strain
+#         file_data[file_name]["user_initial"] = user_initial
+#         file_data[file_name]["antibiotic"] = antibiotic
+#         file_data[file_name]["abxconcentration"] = antibiotic_contration
+#         file_data[file_name]["repeat"] = repeat
+#         file_data[file_name]["usermeta1"] = "Direct From Plate"
+#         file_data[file_name]["usermeta2"] = "Plate2"
+#         file_data[file_name]["usermeta3"] = usermeta3
+#         file_data[file_name]["protocol"] = ""
+#         file_data[file_name]["image_content"] = "E.Coli"
+#         file_data[file_name]["mount"] = "Agarose Pillars"
+#         file_data[file_name]["strain"] = strain
         
-        upload_data.append(file_data[file_name])
+#         upload_data.append(file_data[file_name])
 
-upload_data = pd.DataFrame.from_dict(upload_data)
+# upload_data = pd.DataFrame.from_dict(upload_data)
 
-upload_data = upload_data.sort_values(["well_position","position_index"])
+# upload_data = upload_data.sort_values(["well_position","position_index"])
     
-upload_data = upload_data.groupby(["well_position_name","fov_index"])
+# upload_data = upload_data.groupby(["well_position_name","fov_index"])
 
-upload_data = [upload_data.get_group(list(upload_data.groups)[index]) for index in range(len(upload_data))]
+# upload_data = [upload_data.get_group(list(upload_data.groups)[index]) for index in range(len(upload_data))]
 
 
-user_metadata_path = os.path.join(r"\\physics\dfs\DAQ\CondensedMatterGroups\AKGroup\Piers\AKSEG\Images", user_initial, f"{user_initial}_file_metadata.txt")
-user_metadata = pd.read_csv(user_metadata_path, sep=",", low_memory=False)
+# user_metadata_path = os.path.join(r"\\physics\dfs\DAQ\CondensedMatterGroups\AKGroup\Piers\AKSEG\Images", user_initial, f"{user_initial}_file_metadata.txt")
+# user_metadata = pd.read_csv(user_metadata_path, sep=",", low_memory=False)
 
-user_metadata["file_list"] = user_metadata["file_list"].apply(lambda data: extract_list(data))
-user_metadata["channel_list"] = user_metadata["channel_list"].apply(lambda data: extract_list(data, mode="channel"))
+# user_metadata["file_list"] = user_metadata["file_list"].apply(lambda data: extract_list(data))
+# user_metadata["channel_list"] = user_metadata["channel_list"].apply(lambda data: extract_list(data, mode="channel"))
 
-user_metadata["file_name"] = user_metadata["file_list"]
-user_metadata["channel"] = user_metadata["channel_list"]
+# user_metadata["file_name"] = user_metadata["file_list"]
+# user_metadata["channel"] = user_metadata["channel_list"]
 
-user_metadata = user_metadata.explode(["file_name", "channel"])
+# user_metadata = user_metadata.explode(["file_name", "channel"])
 
-user_metadata = user_metadata.drop_duplicates(["segmentation_file", "folder", "content"])
+# user_metadata = user_metadata.drop_duplicates(["segmentation_file", "folder", "content"])
 
-# user_metadata = user_metadata[user_metadata["user_meta1"]!="Direct From Plate"]
+# # user_metadata = user_metadata[user_metadata["user_meta1"]!="Direct From Plate"]
 
-if __name__=='__main__':
+# if __name__=='__main__':
     
-#     with Pool() as p:
+# #     with Pool() as p:
         
-#         results = list(tqdm.tqdm(p.imap(upload_files,upload_data), total=len(upload_data)))
-#         p.close()
-#         p.join()
+# #         results = list(tqdm.tqdm(p.imap(upload_files,upload_data), total=len(upload_data)))
+# #         p.close()
+# #         p.join()
         
-#         results = [item for item in results if results!=None]
-#         results = [file_metadata for file_metadata_list in results for file_metadata in file_metadata_list if file_metadata!=None]
+# #         results = [item for item in results if results!=None]
+# #         results = [file_metadata for file_metadata_list in results for file_metadata in file_metadata_list if file_metadata!=None]
         
-#         new_metadata = pd.DataFrame.from_dict(results)
+# #         new_metadata = pd.DataFrame.from_dict(results)
 
-#     with open('new_metadata.pickle', 'wb') as handle:
-#         pickle.dump(new_metadata, handle, protocol=pickle.HIGHEST_PROTOCOL)
+# #     with open('new_metadata.pickle', 'wb') as handle:
+# #         pickle.dump(new_metadata, handle, protocol=pickle.HIGHEST_PROTOCOL)
 
-    with open('new_metadata.pickle', 'rb') as handle:
-        new_metadata = pickle.load(handle)
+#     with open('new_metadata.pickle', 'rb') as handle:
+#         new_metadata = pickle.load(handle)
 
-    user_metadata = pd.concat([user_metadata,new_metadata],ignore_index=True).reset_index(drop=True)
+#     user_metadata = pd.concat([user_metadata,new_metadata],ignore_index=True).reset_index(drop=True)
     
-    user_metadata = user_metadata.drop_duplicates(subset=['akseg_hash'],keep="last")
+#     user_metadata = user_metadata.drop_duplicates(subset=['akseg_hash'],keep="last")
     
-    user_metadata.to_csv(user_metadata_path, sep=",", index = False) 
+#     user_metadata.to_csv(user_metadata_path, sep=",", index = False) 
 
 
 
